==> bad_ads_blocker_v3.4.tar.gz: bad_ads_blocker/advertisers.php <==
<?php //—
$start_time=time();
include_once 'functions.php';

if(!is_still_log_in())	{
    die('<p>You should log in to Google first</p>');
}

$first_result=curl_get($GLOBALS['arc_tab_req_string'], '', '');

if(isset($set['log'])) file_put_contents($GLOBALS['temp_folder'].'logs/s1'.time(), $first_result);

unset($first_result);

/**
* Get first access tokens:
**/

$url='https://www.google.com/adsense/gwt-properties?pid='.$GLOBALS['pub_id'].'&authuser=0&tpid='.$GLOBALS['pub_id'].'&ov=3';
$result=curl_post($url, '', $GLOBALS['arc_tab_req_string'], $GLOBALS['myheaders']); // Requesting access tokens in meta tags

if(isset($set['log'])) file_put_contents($GLOBALS['temp_folder'].'logs/s2_gwt'.time(), $result);

$gwtarray=metagwt2array($result); // Converting data to array
file_put_contents($GLOBALS['xsrftoken_file'], $gwtarray['syn_token_pb']); // Put XSRF new token

$list=get_advertisers_list ();

$out='';
$i=0;
foreach($list->result->{1} as $adv_obj) {
	
	$adv_id=$adv_obj->{1}->{1}->{1};
	@$adv_name=trim($adv_obj->{2}.' '.$adv_obj->{3});
	if($adv_obj->{2})	$accs_ads_filename=md5($adv_obj->{2});
	else				$accs_ads_filename=$adv_obj->{3};
	if(file_exists($GLOBALS['temp_folder'].'accs_ads/'.$accs_ads_filename)) {
		$adv_title=file_get_contents($GLOBALS['temp_folder'].'accs_ads/'.$accs_ads_filename);
		$adv_title=' title="'.$adv_title.'"';
	} else $adv_title='';
	
	
	if(@$_POST['confirmation']=='agree') {
		$result=unblock_adwords_account($adv_id);
		if(is_object($result->error)) 
			die('<p>'.$result->error->code.' '.$result->error->message.'</p>');

		$result=$result->result->{1};
		$result=$result[0]->{1};
		if($result) {
			$result=' unblocked';
			$out.=$adv_name.$result.'<br />';
			unlink($GLOBALS['temp_folder'].'autoblocked_accs/'.$adv_obj->{3});
			unlink($GLOBALS['temp_folder'].'accs_ads/'.$accs_ads_filename);
		}
		if($i>=100) break;
	} else
		$out.="<span$adv_title>$adv_name</span> <a href=\"blocker.php?type=adwords_acc&act=unblock&ad_id=".rawurlencode($adv_id)."\" target=\"working_frame\" class=\"unblock unblock_acc\" title=\"Unblock AdWords account\" ><img src=\"img/unblock.png\" />AdWords account</a> <a href=\"blocker.php?type=adwords_acc&act=block&ad_id=".rawurlencode($adv_id)."\" target=\"working_frame\" class=\"unblock unblock_acc\" title=\"Block AdWords account\" ><img src=\"img/block.png\" />AdWords account</a><br />";
	$i++;
}

/*
if(@$_POST['confirmation']=='agree') {		// Acc folder cleaning
	
	$acc_files=scandir($GLOBALS['temp_folder'].'autoblocked_accs');
	
	foreach($acc_files as $acc_file) {
		if($acc_file!='.'&&$acc_file!='..') 
			unlink($GLOBALS['temp_folder'].'autoblocked_accs/'.$acc_file);
	}
}
*/			

$exe_time=time()-$start_time;
$exe_time=date("i:s", $exe_time);
?>
<!DOCTYPE html>
<html>
<head>

<title>Advertisers account list</title>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="referrer" content="same-origin" />
<meta name="robots" content="noindex, nofollow" />
<link href="img/favicon.ico" rel="shortcut icon" type="image/x-icon" />
<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=4, minimum-scale=0.1" />
<link rel="stylesheet" type="text/css" href="style.css"/>
<style>
* { font-size: 16px;  font-family: Calibri, Verdana, Arial; }
body { background: #fff; }
.working_frame { max-width: 400px; height:700px; }

span[title] { color:#999; }

a.block, a.unblock {
	font-size: 14px;
    line-height: 12px;
	border: solid 1px #c6c6c6;
    color: #444;
    display: inline-block;
    padding: 5px 3px;
    margin: 5px 0px;
    font-family: Arial,Helvetica,sans-serif;
    text-decoration: none;
	background-image: -webkit-gradient(linear,left top,left bottom,from(#f6f6f6),to(#f1f1f1));
    background-image: -webkit-linear-gradient(top,#f6f6f6,#f1f1f1);
    -webkit-box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
    box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
}

a.block:active, a.unblock:active { 
	background-image: -webkit-gradient(linear,left top,left bottom,from(#f6f6f6),to(#f1f1f1));
    background-image: -webkit-linear-gradient(top,#f6f6f6,#f1f1f1);
    background-color: #f6f6f6;
}

a.block:hover, a.unblock:hover { 
    background-image: -webkit-gradient(linear,left top,left bottom,from(#f8f8f8),to(#f1f1f1));
    background-image: -webkit-linear-gradient(top,#f8f8f8,#f1f1f1);
    background-color: #f8f8f8;
    border-color: #c6c6c6;
    color: #222;
    -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.1);
}
input[type="submit"], button { max-width: 200px; margin: 3px; }


</style>

</head>
<body>
<?php
if(!isset($_POST['confirmation'])) {
?>

	<form method="post" target="working_frame" >
	
	<label>
		Do you want to unblock all accounts?<br />
		You should type «agree» to confirm.<br />
		<input type="text" name="confirmation" placeholder="Type «agree»" required autocomplete="off"/><br />
	</label>
	<br />

	<input class="submit" type="submit" value="Start unblocking process" />

	</form>
<h3>Total <?=$i?> Account blocked</h3>

<?php
}
?>

<p>Execution time: <?=$exe_time?>.</p>
<p class="adv_ids">

<?=$out?>
</p>

<?php
if(!isset($_POST['confirmation'])) {
?>
<iframe class="working_frame" name="working_frame" id="working_frame" ></iframe>
<?php
}
?>


</body>
</html>

==> bad_ads_blocker_v3.4.1.tar.gz: bad_ads_blocker/advertisers.php <==
<?php //—
$start_time=time();
include_once 'functions.php';

if(!is_still_log_in())	{
    die('<p>You should log in to Google first</p>');
}

$first_result=curl_get($GLOBALS['arc_tab_req_string'], '', '');

if(isset($set['log'])) file_put_contents($GLOBALS['temp_folder'].'logs/s1'.time(), $first_result);

unset($first_result);

/**
* Get first access tokens:
**/

$url='https://www.google.com/adsense/gwt-properties?pid='.$GLOBALS['pub_id'].'&authuser=0&tpid='.$GLOBALS['pub_id'].'&ov=3';
$result=curl_post($url, '', $GLOBALS['arc_tab_req_string'], $GLOBALS['myheaders']); // Requesting access tokens in meta tags

if(isset($set['log'])) file_put_contents($GLOBALS['temp_folder'].'logs/s2_gwt'.time(), $result);

$gwtarray=metagwt2array($result); // Converting data to array
file_put_contents($GLOBALS['xsrftoken_file'], $gwtarray['syn_token_pb']); // Put XSRF new token

$list=get_advertisers_list ();

$out='';
$i=0;
foreach($list->result->{1} as $adv_obj) {
	
	$adv_id=$adv_obj->{1}->{1}->{1};
	@$adv_name=trim($adv_obj->{2}.' '.$adv_obj->{3});
	if($adv_obj->{2})	$accs_ads_filename=md5($adv_obj->{2});
	else				$accs_ads_filename=$adv_obj->{3};
	if(file_exists($GLOBALS['temp_folder'].'accs_ads/'.$accs_ads_filename)) {
		$adv_title=file_get_contents($GLOBALS['temp_folder'].'accs_ads/'.$accs_ads_filename);
		$list=explode("\n", $adv_title, 2);
		$adv_title=' title="'.$adv_title.'"';
		$ads_first_line=' '.mb_substr($list[0], 0, 30, 'UTF-8');
	} else {
		$adv_title='';
		$ads_first_line='';
	}
	
	
	if(@$_POST['confirmation']=='agree') {
		$result=unblock_adwords_account($adv_id);
		if(is_object($result->error)) 
			die('<p>'.$result->error->code.' '.$result->error->message.'</p>');

		$result=$result->result->{1};
		$result=$result[0]->{1};
		if($result) {
			$result=' unblocked';
			$out.=$adv_name.$result.'<br />';
			unlink($GLOBALS['temp_folder'].'autoblocked_accs/'.$adv_obj->{3});
			unlink($GLOBALS['temp_folder'].'accs_ads/'.$accs_ads_filename);
		}
		if($i>=100) break;
	} else
		$out.="<span$adv_title>$adv_name</span> <a href=\"blocker.php?type=adwords_acc&act=unblock&ad_id=".rawurlencode($adv_id)."\" target=\"working_frame\" class=\"unblock unblock_acc\" title=\"Unblock AdWords account\" ><img src=\"img/unblock.png\" />AdWords account</a> <a href=\"blocker.php?type=adwords_acc&act=block&ad_id=".rawurlencode($adv_id)."\" target=\"working_frame\" class=\"unblock unblock_acc\" title=\"Block AdWords account\" ><img src=\"img/block.png\" />AdWords account</a>$ads_first_line<br />";
	$i++;
}

/*
if(@$_POST['confirmation']=='agree') {		// Acc folder cleaning
	
	$acc_files=scandir($GLOBALS['temp_folder'].'autoblocked_accs');
	
	foreach($acc_files as $acc_file) {
		if($acc_file!='.'&&$acc_file!='..') 
			unlink($GLOBALS['temp_folder'].'autoblocked_accs/'.$acc_file);
	}
}
*/			

$exe_time=time()-$start_time;
$exe_time=date("i:s", $exe_time);
?>
<!DOCTYPE html>
<html>
<head>

<title>Advertisers account list</title>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="referrer" content="same-origin" />
<meta name="robots" content="noindex, nofollow" />
<link href="img/favicon.ico" rel="shortcut icon" type="image/x-icon" />
<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=4, minimum-scale=0.1" />
<link rel="stylesheet" type="text/css" href="style.css"/>
<style>
* { font-size: 16px;  font-family: Calibri, Verdana, Arial; }
body { background: #fff; }
.working_frame { max-width: 400px; height:700px; }

span[title] { color:#999; }

a.block, a.unblock {
	font-size: 14px;
    line-height: 12px;
	border: solid 1px #c6c6c6;
    color: #444;
    display: inline-block;
    padding: 5px 3px;
    margin: 5px 0px;
    font-family: Arial,Helvetica,sans-serif;
    text-decoration: none;
	background-image: -webkit-gradient(linear,left top,left bottom,from(#f6f6f6),to(#f1f1f1));
    background-image: -webkit-linear-gradient(top,#f6f6f6,#f1f1f1);
    -webkit-box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
    box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
}

a.block:active, a.unblock:active { 
	background-image: -webkit-gradient(linear,left top,left bottom,from(#f6f6f6),to(#f1f1f1));
    background-image: -webkit-linear-gradient(top,#f6f6f6,#f1f1f1);
    background-color: #f6f6f6;
}

a.block:hover, a.unblock:hover { 
    background-image: -webkit-gradient(linear,left top,left bottom,from(#f8f8f8),to(#f1f1f1));
    background-image: -webkit-linear-gradient(top,#f8f8f8,#f1f1f1);
    background-color: #f8f8f8;
    border-color: #c6c6c6;
    color: #222;
    -webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.1);
}
input[type="submit"], button { max-width: 200px; margin: 3px; }


</style>

</head>
<body>
<?php
if(!isset($_POST['confirmation'])) {
?>

	<form method="post" target="working_frame" >
	
	<label>
		Do you want to unblock all accounts?<br />
		You should type «agree» to confirm.<br />
		<input type="text" name="confirmation" placeholder="Type «agree»" required autocomplete="off"/><br />
	</label>
	<br />

	<input class="submit" type="submit" value="Start unblocking process" />

	</form>
<h3>Total <?=$i?> Account blocked</h3>

<?php
}
?>

<p>Execution time: <?=$exe_time?>.</p>
<p class="adv_ids">

<?=$out?>
</p>

<?php
if(!isset($_POST['confirmation'])) {
?>
<iframe class="working_frame" name="working_frame" id="working_frame" ></iframe>
<?php
}
?>


</body>
</html>
